.. _installation:

Installation
------------

Install through pip using one of the following commands:

.. code-block:: bash

   pip install dbt-contracts
   # or
   python -m pip install dbt-contracts

dbt-contracts is best utilised when used in conjunction with `pre-commit` hooks.
Follow the installation guide for `pre-commit <https://pre-commit.com/#installation>`_ to set this up if needed.
